==> qtjambi-quick-debuginfo-macos-5.15.17.jar: sources/QtJambiQuick/QSGGeometry_AttributeSet_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_AttributeSet(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::AttributeSet")
    QSGGeometry::AttributeSet *_ptr = reinterpret_cast<QSGGeometry::AttributeSet *>(ptr);
    if(!isShell){
        delete[] _ptr->attributes;
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGGeometry_AttributeSet_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    jobjectArray attributes = static_cast<jobjectArray>(__java_arguments[0].l);
    jint stride = __java_arguments[1].i;
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet();


    __qt_this->stride = stride;
    __qt_this->count = __jni_env->GetArrayLength(attributes);
    QSGGeometry::Attribute* _attributes = new QSGGeometry::Attribute[size_t(__qt_this->count)];
    __qt_this->attributes = _attributes;
    for(jsize i=0; i<jsize(__qt_this->count); ++i){
        jobject element = __jni_env->GetObjectArrayElement(attributes, i);
        _attributes[i] = qtjambi_cast<const QSGGeometry::Attribute&>(__jni_env, element);
    }
    Q_UNUSED(__jni_object)
}

// destruct QSGGeometry::AttributeSet
void __qt_destruct_QSGGeometry_AttributeSet(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::AttributeSet")
    reinterpret_cast<QSGGeometry::AttributeSet*>(ptr)->~AttributeSet();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::AttributeSet::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2_3Lio_qt_quick_QSGGeometry_00024Attribute_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobjectArray attributes,
 jint stride)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = attributes;
        arguments[0].i = stride;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet_0, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_operator_1equal_1native_1cref_1QSGGeometry_1AttributeSet__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)", __qt_this)
        const QSGGeometry::AttributeSet& __qt_value21 = QtJambiAPI::objectReferenceFromNativeId<QSGGeometry::AttributeSet>(__jni_env, value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jobjectArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_attributes_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    jobjectArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::Attribute*  __qt_value = __qt_this->attributes;
        __java_return_value = qtjambi_array_cast<jobjectArray>(__jni_env, __qtjambi_scope, __qt_value, __qt_this->count);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_count_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->count;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_AttributeSet(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet", "io/qt/quick/QSGGeometry$AttributeSet");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_AttributeSet, {
        ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet_0, "[Lio/qt/quick/QSGGeometry$Attribute;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_AttributeSet);
    registerMetaType<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-macos-5.15.18.jar: sources/QtJambiQuick/QSGGeometry_AttributeSet_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQuick/qsggeometry.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiQuick/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QSGGeometry_AttributeSet(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGGeometry::AttributeSet")
    QSGGeometry::AttributeSet *_ptr = reinterpret_cast<QSGGeometry::AttributeSet *>(ptr);
    if(!isShell){
        delete[] _ptr->attributes;
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QSGGeometry_AttributeSet_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    jobjectArray attributes = static_cast<jobjectArray>(__java_arguments[0].l);
    jint stride = __java_arguments[1].i;
    QSGGeometry::AttributeSet *__qt_this = new(__qtjambi_ptr) QSGGeometry::AttributeSet();


    __qt_this->stride = stride;
    __qt_this->count = __jni_env->GetArrayLength(attributes);
    QSGGeometry::Attribute* _attributes = new QSGGeometry::Attribute[size_t(__qt_this->count)];
    __qt_this->attributes = _attributes;
    for(jsize i=0; i<jsize(__qt_this->count); ++i){
        jobject element = __jni_env->GetObjectArrayElement(attributes, i);
        _attributes[i] = qtjambi_cast<const QSGGeometry::Attribute&>(__jni_env, element);
    }
    Q_UNUSED(__jni_object)
}

// destruct QSGGeometry::AttributeSet
void __qt_destruct_QSGGeometry_AttributeSet(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGGeometry::AttributeSet")
    reinterpret_cast<QSGGeometry::AttributeSet*>(ptr)->~AttributeSet();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGGeometry::AttributeSet::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_initialize_1native__Lio_qt_quick_QSGGeometry_00024AttributeSet_2_3Lio_qt_quick_QSGGeometry_00024Attribute_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobjectArray attributes,
 jint stride)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGGeometry::AttributeSet::")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = attributes;
        arguments[0].i = stride;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGGeometry_AttributeSet_0, sizeof(QSGGeometry::AttributeSet), typeid(QSGGeometry::AttributeSet), false, &deleter_QSGGeometry_AttributeSet, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_equals_1native_1cref_1QSGGeometry_1AttributeSet__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGGeometry::AttributeSet::operator==(QSGGeometry::AttributeSet,QSGGeometry::AttributeSet)", __qt_this)
        const QSGGeometry::AttributeSet& __qt_value21 = QtJambiAPI::objectReferenceFromNativeId<QSGGeometry::AttributeSet>(__jni_env, value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT jobjectArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_attributes_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    jobjectArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QSGGeometry::Attribute*  __qt_value = __qt_this->attributes;
        __java_return_value = qtjambi_array_cast<jobjectArray>(__jni_env, __qtjambi_scope, __qt_value, __qt_this->count);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_count_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->count;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_stride_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->stride;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGGeometry_00024AttributeSet_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QSGGeometry::AttributeSet *__qt_this = QtJambiAPI::objectFromNativeId<QSGGeometry::AttributeSet>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QSGGeometry_AttributeSet(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet", "io/qt/quick/QSGGeometry$AttributeSet");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QSGGeometry_AttributeSet, {
        ConstructorInfo(&__qt_construct_QSGGeometry_AttributeSet_0, "[Lio/qt/quick/QSGGeometry$Attribute;I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGGeometry_AttributeSet);
    registerMetaType<QSGGeometry::AttributeSet>("QSGGeometry::AttributeSet");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
